@@ -32,16 +32,28 @@
 #' }
 
 subset_clusters_by_id <- function(x, id){
-    net <- as.igraph.epicontacts(x)
-    cs <- igraph::clusters(net)
-    net_nodes <- data.frame(nodes =igraph::V(net)$id,
-                            cs_member = cs$membership,
-                            stringsAsFactors = FALSE)
-    cluster_to_subset <- unique(net_nodes$cs_member[which(net_nodes$nodes %in% id)])
-    id_to_subset <- net_nodes$nodes[ which(net_nodes$cs_member %in% cluster_to_subset)]
-    epi_subset <- x[id_to_subset]
-    return(epi_subset)
+
+  ## Convert epicontacts object to igraph and get linelist + contacts dataframes
+  net <- as.igraph.epicontacts(x)
+
+  ## Get cluster information for each node/case
+  cs <- igraph::clusters(net)
+  net_nodes <- data.frame(nodes =igraph::V(net)$id,
+                          cs_member = cs$membership,
+                          stringsAsFactors = FALSE)
+
+  ## Identify cluster containing nodes/cases of interest
+  cluster_to_subset <- unique(net_nodes$cs_member[which(net_nodes$nodes %in% id)])
+
+  ## Identify members of cluster belonging to nodes/cases of interest
+  id_to_subset <- net_nodes$nodes[ which(net_nodes$cs_member %in% cluster_to_subset)]
+
+  ## Subset linelist and contacts by ids - use 'either' so that all contacts of
+  ## interest are returned, these can be removed using thin if need be later
+  epi_subset <- x[i = id_to_subset,
+                  j = id_to_subset,
+                  contacts = 'either']
+  
+  return(epi_subset)
+  
 }
-
-
-
